@@ -253,3 +253,11 @@ class ParaDateFiledServer(object):
         timeLabel_Info = time_Info['timeLabel']
 
         return timeLabel_Info
+
+    def now_time(self):
+        now_times = time.strftime("%H:%M", time.localtime())
+        return now_times
+
+    def five_feature_time(self):
+        five_feature_times = (datetime.datetime.now()+datetime.timedelta(minutes=5)).strftime('%H:%M')
+        return five_feature_times
\ No newline at end of file
